package com.hw.mes.mapper;

import java.util.List;
import com.hw.mes.domain.MesBaseProdlineInfo;

/**
 * 产线信息Mapper接口
 * 
 * @author Yinq
 * @date 2024-01-24
 */
public interface MesBaseProdlineInfoMapper 
{
    /**
     * 查询产线信息
     * 
     * @param prodlineId 产线信息主键
     * @return 产线信息
     */
    public MesBaseProdlineInfo selectMesBaseProdlineInfoByProdlineId(Long prodlineId);

    /**
     * 查询产线信息列表
     * 
     * @param mesBaseProdlineInfo 产线信息
     * @return 产线信息集合
     */
    public List<MesBaseProdlineInfo> selectMesBaseProdlineInfoList(MesBaseProdlineInfo mesBaseProdlineInfo);

    /**
     * 新增产线信息
     * 
     * @param mesBaseProdlineInfo 产线信息
     * @return 结果
     */
    public int insertMesBaseProdlineInfo(MesBaseProdlineInfo mesBaseProdlineInfo);

    /**
     * 修改产线信息
     * 
     * @param mesBaseProdlineInfo 产线信息
     * @return 结果
     */
    public int updateMesBaseProdlineInfo(MesBaseProdlineInfo mesBaseProdlineInfo);

    /**
     * 删除产线信息
     * 
     * @param prodlineId 产线信息主键
     * @return 结果
     */
    public int deleteMesBaseProdlineInfoByProdlineId(Long prodlineId);

    /**
     * 批量删除产线信息
     * 
     * @param prodlineIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMesBaseProdlineInfoByProdlineIds(Long[] prodlineIds);
}
